@@ -6,8 +6,7 @@ from threading import Thread
 import pytest
 
 from anyio import (
-    BrokenResourceError, EndOfStream, connect_tcp, create_event, create_task_group,
-    create_tcp_listener)
+    BrokenResourceError, EndOfStream, Event, connect_tcp, create_task_group, create_tcp_listener)
 from anyio.abc import AnyByteStream, SocketAttribute, SocketStream
 from anyio.streams.tls import TLSAttribute, TLSListener, TLSStream
 
@@ -76,6 +75,7 @@ class TestTLSStream:
             assert isinstance(wrapper.extra(TLSAttribute.ssl_object), ssl.SSLObject)
             assert wrapper.extra(TLSAttribute.standard_compatible) is False
             assert wrapper.extra(TLSAttribute.tls_version).startswith('TLSv')
+            await wrapper.send(b'\x00')
 
         server_thread.join()
         server_sock.close()
@@ -266,18 +266,18 @@ class TestTLSListener:
                 await super().handle_handshake_error(exc, stream)
                 assert isinstance(stream, SocketStream)
                 exception = exc
-                await event.set()
+                event.set()
 
         exception = None
-        event = create_event()
+        event = Event()
         listener = await create_tcp_listener(local_host='127.0.0.1')
         tls_listener = CustomTLSListener(listener, server_context)
         async with tls_listener, create_task_group() as tg:
-            await tg.spawn(tls_listener.serve, handler)
+            tg.start_soon(tls_listener.serve, handler)
             sock = socket.socket()
             sock.connect(listener.extra(SocketAttribute.local_address))
             sock.close()
             await event.wait()
-            await tg.cancel_scope.cancel()
+            tg.cancel_scope.cancel()
 
         assert isinstance(exception, BrokenResourceError)
