@@ -542,6 +542,29 @@ async def test_shielding_immediate_scope_cancelled():
     assert not sleep_completed
 
 
+async def test_shielding_mutate():
+    async def task(task_status):
+        nonlocal completed
+        with CancelScope() as scope:
+            # Enable the shield a little after the scope starts to make this test
+            # general, even though it has no bearing on the current implementation.
+            await sleep(.1)
+            scope.shield = True
+            task_status.started()
+            await sleep(.1)
+            completed = True
+            scope.shield = False
+            await sleep(1)
+            pytest.fail('Execution should not reach this point')
+
+    completed = False
+    async with create_task_group() as tg:
+        await tg.start(task)
+        tg.cancel_scope.cancel()
+
+    assert completed
+
+
 async def test_cancel_scope_in_child_task():
     async def child():
         nonlocal child_scope
@@ -884,3 +907,44 @@ async def test_cancelscope_exit_in_wrong_task():
     with pytest.raises(RuntimeError):
         async with create_task_group() as tg:
             tg.start_soon(exit_scope, scope)
+
+
+def test_unhandled_exception_group(caplog):
+    def crash():
+        raise KeyboardInterrupt
+
+    async def nested():
+        async with anyio.create_task_group() as tg:
+            tg.start_soon(anyio.sleep, 5)
+            await anyio.sleep(5)
+
+    async def main():
+        async with anyio.create_task_group() as tg:
+            tg.start_soon(nested)
+            await wait_all_tasks_blocked()
+            asyncio.get_event_loop().call_soon(crash)
+            await anyio.sleep(5)
+
+        pytest.fail('Execution should never reach this point')
+
+    with pytest.raises(KeyboardInterrupt):
+        anyio.run(main, backend='asyncio')
+
+    assert not caplog.messages
+
+
+@pytest.mark.skipif(sys.version_info < (3, 9),
+                    reason='Cancel messages are only supported on py3.9+')
+@pytest.mark.parametrize('anyio_backend', ['asyncio'])
+async def test_cancellederror_combination_with_message():
+    async def taskfunc(*, task_status):
+        task_status.started(asyncio.current_task())
+        await sleep(5)
+        pytest.fail('Execution should never reach this point')
+
+    with pytest.raises(asyncio.CancelledError, match='blah'):
+        async with create_task_group() as tg:
+            task = await tg.start(taskfunc)
+            tg.start_soon(sleep, 5)
+            await wait_all_tasks_blocked()
+            task.cancel('blah')
