@@ -2,6 +2,7 @@ import asyncio
 import sys
 import threading
 import time
+from functools import partial
 
 import pytest
 
@@ -84,7 +85,6 @@ async def test_cancel_worker_thread(cancellable, expected_last_active):
 
     """
     def thread_worker():
-        print('thread worker:', threading.current_thread(), flush=True)
         nonlocal last_active
         from_thread.run_sync(sleep_event.set)
         time.sleep(0.2)
@@ -148,3 +148,32 @@ def test_asyncio_no_root_task(asyncio_event_loop):
         if t.name == 'AnyIO worker thread':
             t.join(2)
             assert not t.is_alive()
+
+
+def test_asyncio_future_callback_partial(asyncio_event_loop):
+    """
+    Regression test for #272.
+
+    Ensures that futures with partial callbacks are handled correctly when the root task
+    cannot be determined.
+    """
+    def func(future):
+        pass
+
+    async def sleep_sync():
+        return await to_thread.run_sync(time.sleep, 0)
+
+    task = asyncio_event_loop.create_task(sleep_sync())
+    task.add_done_callback(partial(func))
+    asyncio_event_loop.run_until_complete(task)
+
+
+def test_asyncio_run_sync_no_asyncio_run(asyncio_event_loop):
+    """Test that the thread pool shutdown callback does not raise an exception."""
+    def exception_handler(loop, context=None):
+        exceptions.append(context['exception'])
+
+    exceptions = []
+    asyncio_event_loop.set_exception_handler(exception_handler)
+    asyncio_event_loop.run_until_complete(to_thread.run_sync(time.sleep, 0))
+    assert not exceptions
